var everBeenCalled = false;
var container;
var baseURL = "http://www.dailymotion.com/rss";
var maxItems = 9;
var freshestId;
var timer;
var isHidden = false;

// list of refresh values
var refreshValueList = new Array();
    refreshValueList.push(30);
    refreshValueList.push(60);
    refreshValueList.push(120);
    refreshValueList.push(300);
    refreshValueList.push(600);

// defaults
var pref = new Object();
    pref.refresh = 30;
    pref.user = "";
    pref.tags = "";

function init()
{
    if(!everBeenCalled)
    {
        container = document.getElementById("video_list");
        loadPreferences();
        initSetupPanel();
        onShow();
        if(window.widget)
        {
            widget.onshow = onShow;
            widget.onhide = onHide;
        }
    }
}

function initSetupPanel()
{
    // refresh combo
    document.getElementById('label_refresh').innerText = "Refresh (min):";
    var _idx = 0;
    for(var i = 0; i < refreshValueList.length; i++)
    {
        if(refreshValueList[i] == pref.refresh)
        {
            _idx = i;
            break;
        }
    }
    populateMenu(document.getElementById('form_refresh'), refreshValueList);
    document.getElementById('form_refresh').options[_idx].selected = true;

    // user param
    document.getElementById('label_user').innerText = "User:";
    document.getElementById('form_user').value = pref.user;

    // tags param
    document.getElementById('label_tags').innerText = "Tags:";
    document.getElementById('form_tags').value = pref.tags;

    if(window.widget)
    {
        createGenericButton(document.getElementById('done'), 'Done',
                            function() {storePreferences(); hideBack()});
    }
}

function populateMenu(select, values)
{
    for(var i = 0; i < values.length; i++)
    {
        var element = document.createElement("option");
        element.innerText = values[i];
        select.appendChild(element);
    }
}

function loadPreferences()
{
    if(window.widget)
    {
        var _pref;

        _pref = widget.preferenceForKey("user");
        if (_pref != null) pref.user = _pref;
        _pref = widget.preferenceForKey("tags");
        if (_pref != null) pref.tags = _pref;
        _pref = widget.preferenceForKey("refresh");
        if (_pref != null) pref.refresh = _pref;
    }
}

function storePreferences()
{
    if(window.widget)
    {
        var _pref;
        var changed = false;
        for(var key in pref)
        {
            if(key == "refresh")
                _pref = refreshValueList[document.getElementById('form_refresh').selectedIndex];
            else
                _pref = document.getElementById('form_'+key).value;
            if(pref[key] != _pref)
            {
                widget.setPreferenceForKey(_pref, key);
                pref[key] = _pref;
                changed = true;
            }
        }
        
        if(changed)
        {
            // reinit the list
            freshestId = null;
            refreshList();
        }
    }
}


function getURL()
{
    var url = baseURL;
    var tags = "";
    if(pref.tags.length)
    {
        tags = pref.tags;
        tags.replace(" ", "+");
    }
    if(pref.user.length)
    {
        if(tags.length)
            return baseURL+"/"+pref.user+"/"+tags;
        else
            return baseURL+"/"+pref.user;
    }
    else
    {
        if(tags.length)
            return baseURL+"/tag/"+tags;
        else
            return baseURL;
    }
}

function updateTimer()
{
    clearTimer();
    timer = setInterval('refreshList();', (pref.refresh > 0 ? pref.refresh : 1) * 60 * 1000);
}
function clearTimer()
{
    clearInterval(timer);
    timer = null;
}

function onShow()
{
    updateTimer();
    refreshList();
    isHidden = false;
}
function onHide()
{
    clearTimer()
    isHidden = true;
}

function refreshList()
{
    var xmlreq = new XMLHttpRequest();
    xmlreq.onload = function(e) {processRefreshResponse(e, xmlreq, buildList);};
    xmlreq.open("GET", getURL());
    xmlreq.setRequestHeader("Cache-Control", "no-cache");                                                  
    xmlreq.send(null);
}

function processRefreshResponse(event, request, callback)
{
    if(request.responseXML)
        callback(request.responseXML);
    else
    {
        alert("There was a problem retrieving the XML data");
        request.abort();
    }
}

function buildList(xml_response)
{
    items = xml_response.getElementsByTagName("item");
    if(freshestId == null)
    {
        container.innerHTML = "";
        // it's first time we build the list, start from zero
        for(var i = 0; i < items.length && i < maxItems; i++)
        {
            var id = getItemId(items[i]);
            if(i == 0) freshestId = id;
            appendItem(id, i);
        }
    }
    else
    {
        // the list have already been build, we will do an incremental build if needed
        var newIds = new Array();
        var stopAtId = freshestId;
        for(var i = 0; i < items.length && i < maxItems; i++)
        {
            var id = getItemId(items[i]);
            if(id == stopAtId) break;
            if(i == 0) freshestId = id;
            newIds.push(id);
        }

        if(newIds.length > 0)
        {
            var lastValidItemId = maxItems - newIds.length - 1;
            // delete obsolete items
            for(var i = maxItems - 1; i > lastValidItemId; i--)
            {
                var item = getItem(i);
                if(item != null)
                    item.parentNode.removeChild(item);
            }
            // shift former items
            for(var i = lastValidItemId; i >= 0; i--)
                getItem(i).setAttribute("id", "item"+(i+newIds.length));
            // insert new items
            for(var i = 0; i < newIds.length; i++)
                appendItem(newIds[i], i);
        }
    }
}

function appendItem(id, index)
{
    var mainContainer = document.createElement("div");
    mainContainer.setAttribute("style", "height: 60px");
    mainContainer.setAttribute("id", "item"+index);
    var flvContainer = document.createElement("div");
    flvContainer.setAttribute("id", "flvContainer"+id);
    flvContainer.setAttribute("style", "height: 60px;");
    var eventCatcher = document.createElement("div");
    eventCatcher.setAttribute("onclick", "insertPreview("+id+");openLink('http://www.dailymotion.com/video/"+id+"?from=dashboard')");
    eventCatcher.setAttribute("onmouseover", "insertFlv("+id+")");
    eventCatcher.setAttribute("onmouseout", "insertPreview("+id+")");
    eventCatcher.setAttribute("style", "height: 60px; position: relative; top: -60px;");
    mainContainer.appendChild(flvContainer);
    mainContainer.appendChild(eventCatcher);
    container.appendChild(mainContainer);
    insertPreview(id);
}

function insertPreview(id)
{
    if(isHidden) return;
    getFlvContainer(id).innerHTML = '<img src="http://www.dailymotion.com/media/dyn/preview/80x60/'+id+'.jpg?from=dashboard" />';
}

function insertFlv(id)
{
    if(isHidden) return;
    getFlvContainer(id).innerHTML = ''+
'<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000"'+
'        codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"'+
'        width="80" height="60" id="vogroll'+id+'">'+
'<param name="allowScriptAccess" value="sameDomain" />'+
'<param name="movie" value="flvplayer.swf?video_url=http://www.dailymotion.com/media/video/'+id+'.flv?from=dashboard" />'+
'<param name="quality" value="high" />'+
'<param name="bgcolor" value="#000000" />'+
'</object>';
}

function getFlvContainer(id)
{
    return document.getElementById("flvContainer"+id);
}

function getItem(id)
{
    return document.getElementById("item"+id);
}

function openLink(url)
{
    try
    {
        widget.openURL(url);
    }
    catch(e)
    {
        window.open(url, '_top');
    }
}

function getItemId(item)
{
    guid = item.getElementsByTagName("guid")[0].firstChild.nodeValue
    var tokens = guid.split("/");
    return(tokens[tokens.length - 1]);
}

function showBack()
{
    var front = document.getElementById("front");
    var back = document.getElementById("back");
        
    if (window.widget)
        widget.prepareForTransition("ToBack");
                
    front.style.display="none";
    back.style.display="block";
        
    if (window.widget)
        setTimeout ('widget.performTransition();', 0);  
}

function hideBack()
{
    var front = document.getElementById("front");
    var back = document.getElementById("back");
        
    if (window.widget)
        widget.prepareForTransition("ToFront");
                
    back.style.display="none";
    front.style.display="block";

    if (window.widget)
        setTimeout ('widget.performTransition();', 0);
}

var buttonsShown = false;
var animation = {duration:0, starttime:0, to:1.0, now:0.0, from:0.0, elements:null, timer:null};
function mousemove ()
{
    if (!buttonsShown)
    {
        if (animation.timer != null)
        {
            clearInterval (animation.timer);
            animation.timer  = null;
        }
                
        var starttime = (new Date).getTime() - 13;
                
        animation.duration = 500;
        animation.starttime = starttime;
        animation.elements = new Array();
        animation.elements.push(document.getElementById('flip'));
        animation.timer = setInterval ("animate();", 13);
        animation.from = animation.now;
        animation.to = 1.0;
        animate();
        buttonsShown = true;
    }
}
function mouseexit ()
{
    if (buttonsShown)
    {
        // fade in the info button
        if (animation.timer != null)
        {
            clearInterval (animation.timer);
            animation.timer  = null;
        }
                
        var starttime = (new Date).getTime() - 13;
                
        animation.duration = 500;
        animation.starttime = starttime;
        animation.elements = new Array();
        animation.elements.push(document.getElementById('flip'));
        animation.timer = setInterval ("animate();", 13);
        animation.from = animation.now;
        animation.to = 0.0;
        animate();
        buttonsShown = false;
    }
}
function animate()
{
    var T;
    var ease;
    var time = (new Date).getTime();
                
        
    T = limit_3(time-animation.starttime, 0, animation.duration);
        
    if (T >= animation.duration)
    {
        clearInterval (animation.timer);
        animation.timer = null;
        animation.now = animation.to;
    }
    else
    {
        ease = 0.5 - (0.5 * Math.cos(Math.PI * T / animation.duration));
        animation.now = computeNextFloat (animation.from, animation.to, ease);
    }

    for(var i = 0; i < animation.elements.length; i++)
        animation.elements[i].style.opacity = animation.now;
}
function limit_3 (a, b, c)
{
    return a < b ? b : (a > c ? c : a);
}
function computeNextFloat (from, to, ease)
{
    return from + (to - from) * ease;
}

function enterButton(buttonName)
{
    document.getElementById(buttonName+'rollie').style.display = 'block';
}
function exitButton(buttonName)
{
    document.getElementById(buttonName+'rollie').style.display = 'none';
}
